@@ -31,9 +31,13 @@
 
 
 #include "zmath.h"
+#include "alloc.h"
 #include "lib_util.h"
 
 
+#include "banned.h"	/* include after system header <> includes */
+
+
 /*
  * lowhex2bin - quick low order ASCII hex to binary conversion
  *
